# Copyright (c) 2014, 2015  Dave Love, University of Liverpool
# MIT licence, per Fedora policy.

# NB many rpm warnings, mostly undefined-non-weak-symbol, which I
# think are ignorable.

# fixme: Make common package for .spec data files and anything else common
#	 Check on ignored omp pragmas -- from newer openmp?

# In case we can support el6
%if 0%{?el6}
%ifarch ppc64
%bcond_with mpich
%else
%bcond_without mpich
%endif
%else
%bcond_without mpich
%endif

%global shortver %(echo %version|awk -F. '{print $1 "." $2}')

Name:		scalasca
Version:	2.4
Release:	1%{?dist}
Summary:	Toolset for performance analysis of large-scale parallel applications

# ScoutPatternParser and SilasConfigParser are GPL
License:	BSD and GPLv3+
URL:		http://www.scalasca.org/
Source0:	http://apps.fz-juelich.de/scalasca/releases/scalasca/%shortver/dist/%name-%version.tar.gz

BuildRequires:	otf2-devel >= 2.0, cube-devel >= 4.3
BuildRequires:	zlib-devel openmpi-devel chrpath
%if %{with mpich}
BuildRequires:	mpich-devel
%endif
# Necessary to run tests in epel7
BuildRequires:	openssh-clients

%global desc \
Scalasca is a software tool that supports the performance optimization\
of parallel programs by measuring and analyzing their runtime\
behavior. The analysis identifies potential performance bottlenecks –\
in particular those concerning communication and synchronization – and\
offers guidance in exploring their causes.\
\
Scalasca targets mainly scientific and engineering applications based\
on the programming interfaces MPI and OpenMP, including hybrid\
applications based on a combination of the two. The tool has been\
specifically designed for use on large-scale systems, but is also well\
suited for small- and medium-scale HPC platforms.

%description
%desc

%package openmpi
Summary:	Toolset for performance analysis of large-scale parallel applications - openmpi
Requires:	openmpi%{?_isa}


%description openmpi
%desc

This is the openmpi version.

%if %{with mpich}
%package mpich
Summary:	Toolset for performance analysis of large-scale parallel applications - mpich
Requires:	mpich%{?_isa}

%description mpich
%desc

This is the mpich version.
%endif

%package doc
Summary: Documentation for %name
BuildArch: noarch

%description doc
Documentation for %name

%prep
%setup -q
mkdir openmpi mpich simple
rm -r vendor/cubew vendor/otf2	# bundled libraries


%build
# -std=gnu++98 to enable build with gcc6
export MPI_CXXFLAGS=-std=gnu++98 CXXFLAGS=-std=gnu++98
%global _configure ../configure
%global do_build \
%configure --with-otf2 --with-cube --enable-shared --libdir=$MPI_LIB \\\
	   --bindir=$MPI_BIN --datadir=$MPI_HOME/share LDFLAGS=-Wl,--as-needed \\\
	   --enable-backend-test-runs --disable-silent-rules \
	   make %{?_smp_mflags}
pushd openmpi
%_openmpi_load
%do_build
%_openmpi_unload
popd
%if %{with mpich}
pushd mpich
%_mpich_load
%do_build
%_mpich_unload
popd
%endif
pushd simple
%configure --with-otf2 --with-cube --enable-shared LDFLAGS=-Wl,--as-needed \
	   --enable-backend-test-runs --disable-silent-rules --without-mpi
make %{?_smp_mflags}
popd


%install
rm -rf $RPM_BUILD_ROOT
make install -C openmpi DESTDIR=$RPM_BUILD_ROOT
%if %{with mpich}
make install -C mpich DESTDIR=$RPM_BUILD_ROOT
%endif
make install -C simple DESTDIR=$RPM_BUILD_ROOT

find $RPM_BUILD_ROOT%_libdir \( -name \*.la -o -name \*.a \) -exec rm -f {} \;

chrpath -d $RPM_BUILD_ROOT%_libdir/*/lib/libpearl.base.so.0 $RPM_BUILD_ROOT%_libdir/libpearl.base.so.0
chrpath -d $RPM_BUILD_ROOT%_bindir/scout.{ser,omp}
chrpath -d $RPM_BUILD_ROOT%_libdir/{openmpi,mpich}/bin/scout.{ser,omp}


%check
%_openmpi_load
cd openmpi
OMPI_MCA_orte_allocation_required=0 OMPI_MCA_btl=sm,self \
make check VERBOSE=1


%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%{!?_licensedir:%global license %%doc}
%files
%doc README
%license COPYING
%_datadir/%name
%exclude %_libdir/*.so
%_libdir/*.so.*
%_bindir/*

%files openmpi
%doc README
%license COPYING
%_libdir/openmpi/share/%name
%exclude %_libdir/openmpi/lib/*.so
%_libdir/openmpi/lib/*.so.*
%_libdir/openmpi/bin/*

%if %{with mpich}
%files mpich
%doc README
%license COPYING
%_libdir/mpich/share/%name
%exclude %_libdir/mpich/lib/*.so
%_libdir/mpich/lib/*.so.*
%_libdir/mpich/bin/*
%endif

%files doc
%_docdir/%name


%changelog
* Tue Jun 19 2018 Dave Love <loveshack@fedoraproject.org> - %ver-6
- New version (#1578180)

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Oct 21 2016 Orion Poplawski <orion@cora.nwra.com> - 2.3.1-2
- Rebuild for openmpi 2.0

* Fri May 20 2016 Orion Poplawski <orion@cora.nwra.com> - 2.3.1-1
- Update to 2.3.1
- Drop pearl patch applied upstream

* Thu May 12 2016 Dave Love <loveshack@fedoraproject.org> - 2.3-4
- Run ldconfig for main package too, and fix rpath

* Wed May 11 2016 Dave Love <loveshack@fedoraproject.org> - 2.3-3
- Build non-MPI version
  Resolves: rhbz#1334560
- Use separate datadirs; at least summary file is build-dependent

* Sat Apr 16 2016 Orion Poplawski <orion@cora.nwra.com> - 2.3-2
- Just fix test program linkage

* Fri Apr 15 2016 Orion Poplawski <orion@cora.nwra.com> - 2.3-1
- Update to 2.3
- Add patch to fix libpearl_base linkage

* Sun Feb 14 2016 Dave Love <loveshack@fedoraproject.org> - 2.2.2-6
- Set CXX flags to build with gcc6
- Disable silent make rules

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.2.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Sep 15 2015 Orion Poplawski <orion@cora.nwra.com> - 2.2.2-4
- Rebuild for openmpi 1.10.0

* Sat Aug 22 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2.2-3
- BR openssh-clients so test works in koji epel7

* Tue Jul 7 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2.2-2
- Various spec tidying
- Don't build devel package -- doesn't seem useful

* Thu Jun 25 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2.2-1
- New version

* Thu May 28 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2.1-1
- New version

* Sun Feb 22 2015 Dave Love <d.love@liverpool.ac.uk> - 2.2-1
- New version

* Sun Feb 22 2015 Dave Love <d.love@liverpool.ac.uk> - 2.1-6
- Configure and run tests
- Avoid mpich on el6 ppc64
- Remove defattr

* Wed Dec 24 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-5
- Don't install .a files

* Tue Dec 16 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-4
- Modify requires

* Sun Dec 14 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-4
- Fix copyright

* Thu Dec 11 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-3
- Add mpich

* Thu Nov 20 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-2
- Minor rpmlint fixes

* Mon Oct 13 2014 Dave Love <d.love@liverpool.ac.uk> - 2.1-2
- Initial packaging
